==> deepin-font-manager_6.0.3.tar.xz: BUILD/translations/deepin-font-manager_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation type="unfinished">Aceeași versiune este instalată</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Necunoscut</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deactivated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Necunoscut</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installed</source>
        <translation type="unfinished">Instalat</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation type="unfinished">Aceeași versiune este instalată</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Necunoscut</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deactivated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Necunoscut</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installed</source>
        <translation type="unfinished">Instalat</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
